==> v1.0.0.tar.gz: athena/include/Athena/ALTTPFileReader.hpp <==
#ifndef ATHENA_NO_SAVES
// This file is part of libAthena.
//
// libAthena is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// libAthena is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with libAthena.  If not, see <http://www.gnu.org/licenses/>

#ifndef __ALTTP_FILE_READER_HPP__
#define __ALTTP_FILE_READER_HPP__

#include <string>
#include "Athena/Types.hpp"
#include "Athena/BinaryReader.hpp"
#include "Athena/ALTTPQuest.hpp"

namespace Athena
{
class ALTTPFile;

namespace io
{
/*! \class ALTTPFileReader
 *  \brief A Link to the Past save data reader class
 *
 *  A Class for reading binary data from an ALTTP Save File,
 *  all work is done using a memory buffer, and not read directly from the disk.
 *  \sa BinaryReader
 */
class ALTTPFileReader : protected BinaryReader
{
    BINARYREADER_BASE();

public:
    /*! \brief This constructor takes an existing buffer to read from.
     *
     *   \param data The existing buffer
     *   \param length The length of the existing buffer
     */
    ALTTPFileReader(atUint8*, atUint64);

    /*! \brief This constructor creates an instance from a file on disk.
     *
     * \param filename The file to create the stream from
     */
    ALTTPFileReader(const std::string&);

    /*! \brief Reads the SRAM data from the buffer
     *
     * \return ALTTPFile* SRAM data
     */
    ALTTPFile* readFile();
private:
    ALTTPRoomFlags* readRoomFlags();
    ALTTPOverworldEvent* readOverworldEvent();
    ALTTPDungeonItemFlags readDungeonFlags();
};

} // io
} // zelda
#endif // __ALTTP_FILE_READER_HPP__
#endif // ATHENA_NO_SAVES

==> 2.2.0.tar.gz: athena/include/Athena/ALTTPFileReader.hpp <==
#ifndef ATHENA_NO_SAVES
// This file is part of libAthena.
//
// libAthena is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// libAthena is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with libAthena.  If not, see <http://www.gnu.org/licenses/>

#ifndef ALTTP_FILE_READER_HPP
#define ALTTP_FILE_READER_HPP

#include <string>
#include "Athena/Types.hpp"
#include "Athena/MemoryReader.hpp"
#include "Athena/ALTTPQuest.hpp"

namespace Athena
{
class ALTTPFile;

namespace io
{
/*! \class ALTTPFileReader
 *  \brief A Link to the Past save data reader class
 *
 *  A Class for reading binary data from an ALTTP Save File,
 *  all work is done using a memory buffer, and not read directly from the disk.
 *  \sa BinaryReader
 */
class ALTTPFileReader : protected MemoryCopyReader
{
    MEMORYCOPYREADER_BASE();

public:
    /*! \brief This constructor takes an existing buffer to read from.
     *
     *   \param data The existing buffer
     *   \param length The length of the existing buffer
     */
    ALTTPFileReader(atUint8*, atUint64);

    /*! \brief This constructor creates an instance from a file on disk.
     *
     * \param filename The file to create the stream from
     */
    ALTTPFileReader(const std::string&);

    /*! \brief Reads the SRAM data from the buffer
     *
     * \return ALTTPFile* SRAM data
     */
    ALTTPFile* readFile();
private:
    ALTTPRoomFlags* readRoomFlags();
    ALTTPOverworldEvent* readOverworldEvent();
    ALTTPDungeonItemFlags readDungeonFlags();
};

} // io
} // zelda
#endif // ALTTP_FILE_READER_HPP
#endif // ATHENA_NO_SAVES
